@@ -19,18 +19,25 @@
 
 #include "elisautils.h"
 
-#include <KFileMetaData/Properties>
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/Extractor>
 #include <KFileMetaData/SimpleExtractionResult>
 #include <KFileMetaData/UserMetaData>
 
+#include <QFileInfo>
+
 MusicAudioTrack ElisaUtils::scanOneFile(const QUrl &scanFile, const QMimeDatabase &mimeDatabase,
                                         const KFileMetaData::ExtractorCollection &allExtractors)
 {
     MusicAudioTrack newTrack;
 
-    const auto &fileMimeType = mimeDatabase.mimeTypeForFile(scanFile.toLocalFile());
+    auto localFileName = scanFile.toLocalFile();
+
+    QFileInfo scanFileInfo(localFileName);
+    newTrack.setFileModificationTime(scanFileInfo.fileTime(QFile::FileModificationTime));
+    newTrack.setResourceURI(scanFile);
+
+    const auto &fileMimeType = mimeDatabase.mimeTypeForFile(localFileName);
     if (!fileMimeType.name().startsWith(QStringLiteral("audio/"))) {
         return newTrack;
     }
@@ -44,13 +51,20 @@ MusicAudioTrack ElisaUtils::scanOneFile(const QUrl &scanFile, const QMimeDatabas
     }
 
     KFileMetaData::Extractor* ex = exList.first();
-    KFileMetaData::SimpleExtractionResult result(scanFile.toLocalFile(), mimetype,
+    KFileMetaData::SimpleExtractionResult result(localFileName, mimetype,
                                                  KFileMetaData::ExtractionResult::ExtractMetaData);
 
     ex->extract(&result);
 
     const auto &allProperties = result.properties();
 
+    ElisaUtils::scanProperties(localFileName, allProperties, newTrack);
+
+    return newTrack;
+}
+
+void ElisaUtils::scanProperties(const QString localFileName, const KFileMetaData::PropertyMap &allProperties, MusicAudioTrack &trackData)
+{
     auto titleProperty = allProperties.find(KFileMetaData::Property::Title);
     auto durationProperty = allProperties.find(KFileMetaData::Property::Duration);
     auto artistProperty = allProperties.find(KFileMetaData::Property::Artist);
@@ -67,104 +81,87 @@ MusicAudioTrack ElisaUtils::scanOneFile(const QUrl &scanFile, const QMimeDatabas
     auto sampleRateProperty = allProperties.find(KFileMetaData::Property::SampleRate);
     auto commentProperty = allProperties.find(KFileMetaData::Property::Comment);
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    auto fileData = KFileMetaData::UserMetaData(scanFile.toLocalFile());
+    auto fileData = KFileMetaData::UserMetaData(localFileName);
 #endif
 
     if (albumProperty != allProperties.end()) {
-        auto albumValue = albumProperty->toString();
-
-        newTrack.setAlbumName(albumValue);
-
-        if (artistProperty != allProperties.end()) {
-            newTrack.setArtist(artistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (durationProperty != allProperties.end()) {
-            newTrack.setDuration(QTime::fromMSecsSinceStartOfDay(1000 * durationProperty->toDouble()));
-        }
-
-        if (titleProperty != allProperties.end()) {
-            newTrack.setTitle(titleProperty->toString());
-        }
-
-        if (trackNumberProperty != allProperties.end()) {
-            newTrack.setTrackNumber(trackNumberProperty->toInt());
-        }
-
-        if (discNumberProperty != allProperties.end()) {
-            newTrack.setDiscNumber(discNumberProperty->toInt());
-        } else {
-            newTrack.setDiscNumber(1);
-        }
-
-        if (albumArtistProperty != allProperties.end()) {
-            newTrack.setAlbumArtist(albumArtistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (yearProperty != allProperties.end()) {
-            newTrack.setYear(yearProperty->toInt());
-        }
-
-        if (channelsProperty != allProperties.end()) {
-            newTrack.setChannels(channelsProperty->toInt());
-        }
-
-        if (bitRateProperty != allProperties.end()) {
-            newTrack.setBitRate(bitRateProperty->toInt());
-        }
-
-        if (sampleRateProperty != allProperties.end()) {
-            newTrack.setSampleRate(sampleRateProperty->toInt());
-        }
-
-        if (genreProperty != allProperties.end()) {
-            newTrack.setGenre(genreProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (composerProperty != allProperties.end()) {
-            newTrack.setComposer(composerProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (lyricistProperty != allProperties.end()) {
-            newTrack.setLyricist(lyricistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (commentProperty != allProperties.end()) {
-            newTrack.setComment(commentProperty->toString());
-        }
-
-        if (newTrack.artist().isEmpty()) {
-            newTrack.setArtist(newTrack.albumArtist());
-        }
-
-        newTrack.setResourceURI(scanFile);
-
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-        newTrack.setRating(fileData.rating());
-#else
-        newTrack.setRating(0);
-#endif
-
-        if (newTrack.title().isEmpty()) {
-            return newTrack;
-        }
-
-        if (newTrack.artist().isEmpty()) {
-            return newTrack;
-        }
-
-        if (newTrack.albumName().isEmpty()) {
-            return newTrack;
-        }
-
-        if (!newTrack.duration().isValid()) {
-            return newTrack;
-        }
-
-        newTrack.setValid(true);
+        trackData.setAlbumName(albumProperty->toString());
     }
 
-    return newTrack;
+    if (artistProperty != allProperties.end()) {
+        trackData.setArtist(artistProperty->toStringList().join(QStringLiteral(", ")));
+    }
+
+    if (durationProperty != allProperties.end()) {
+        trackData.setDuration(QTime::fromMSecsSinceStartOfDay(int(1000 * durationProperty->toDouble())));
+    }
+
+    if (titleProperty != allProperties.end()) {
+        trackData.setTitle(titleProperty->toString());
+    }
+
+    if (trackNumberProperty != allProperties.end()) {
+        trackData.setTrackNumber(trackNumberProperty->toInt());
+    }
+
+    if (discNumberProperty != allProperties.end()) {
+        trackData.setDiscNumber(discNumberProperty->toInt());
+    } else {
+        trackData.setDiscNumber(1);
+    }
+
+    if (albumArtistProperty != allProperties.end()) {
+        trackData.setAlbumArtist(albumArtistProperty->toStringList().join(QStringLiteral(", ")));
+    }
+
+    if (yearProperty != allProperties.end()) {
+        trackData.setYear(yearProperty->toInt());
+    }
+
+    if (channelsProperty != allProperties.end()) {
+        trackData.setChannels(channelsProperty->toInt());
+    }
+
+    if (bitRateProperty != allProperties.end()) {
+        trackData.setBitRate(bitRateProperty->toInt());
+    }
+
+    if (sampleRateProperty != allProperties.end()) {
+        trackData.setSampleRate(sampleRateProperty->toInt());
+    }
+
+    if (genreProperty != allProperties.end()) {
+        trackData.setGenre(genreProperty->toStringList().join(QStringLiteral(", ")));
+    }
+
+    if (composerProperty != allProperties.end()) {
+        trackData.setComposer(composerProperty->toStringList().join(QStringLiteral(", ")));
+    }
+
+    if (lyricistProperty != allProperties.end()) {
+        trackData.setLyricist(lyricistProperty->toStringList().join(QStringLiteral(", ")));
+    }
+
+    if (commentProperty != allProperties.end()) {
+        trackData.setComment(commentProperty->toString());
+    }
+
+    if (trackData.artist().isEmpty()) {
+        trackData.setArtist(trackData.albumArtist());
+    }
+
+#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+    trackData.setRating(fileData.rating());
+#else
+    trackData.setRating(0);
+#endif
+
+    if (!trackData.duration().isValid()) {
+        return;
+    }
+
+    trackData.setValid(true);
+
 }
 
 
