@@ -71,8 +71,9 @@ void LocalFileListing::setRootPath(const QString &rootPath)
     setSourceName(rootPath);
 }
 
-void LocalFileListing::executeInit()
+void LocalFileListing::executeInit(QHash<QUrl, QDateTime> allFiles)
 {
+    AbstractFileListing::executeInit(std::move(allFiles));
 }
 
 void LocalFileListing::triggerRefreshOfContent()
@@ -83,7 +84,9 @@ void LocalFileListing::triggerRefreshOfContent()
 
     scanDirectoryTree(d->mRootPath);
 
-    Q_EMIT indexingFinished(importedTracksCount());
+    checkFilesToRemove();
+
+    Q_EMIT indexingFinished();
 }
 
 
