@@ -324,13 +324,28 @@ void ManageAudioPlayer::setPlayerError(QMediaPlayer::Error playerError)
     }
 }
 
+void ManageAudioPlayer::ensurePause()
+{
+    if (mPlayingState) {
+        mPlayingState = false;
+        triggerPause();
+    }
+}
+
 void ManageAudioPlayer::ensurePlay()
 {
     if (!mPlayingState) {
-        playPause();
+        mPlayingState = true;
+        triggerPlay();
     }
 }
 
+void ManageAudioPlayer::stop()
+{
+    mPlayingState = false;
+    triggerStop();
+}
+
 void ManageAudioPlayer::playPause()
 {
     mPlayingState = !mPlayingState;
@@ -495,7 +510,7 @@ void ManageAudioPlayer::notifyPlayerSourceProperty()
 {
     auto newUrlValue = mCurrentTrack.data(mUrlRole);
     if ((mCurrentTrack == mOldCurrentTrack && mOldPlayerSource == newUrlValue && mPlayingState) || mOldPlayerSource != newUrlValue) {
-        Q_EMIT playerSourceChanged();
+        Q_EMIT playerSourceChanged(mCurrentTrack.data(mUrlRole).toUrl());
 
         mOldPlayerSource = newUrlValue;
     }
