@@ -43,16 +43,16 @@ public:
 
     QPersistentModelIndex mCurrentTrack;
 
+    QVariantMap mPersistentState;
+
+    QMediaPlaylist mLoadPlaylist;
+
     int mCurrentPlayListPosition = 0;
 
     bool mRandomPlay = false;
 
     bool mRepeatPlay = false;
 
-    QVariantMap mPersistentState;
-
-    QMediaPlaylist mLoadPlaylist;
-
 };
 
 MediaPlayList::MediaPlayList(QObject *parent) : QAbstractListModel(parent), d(new MediaPlayListPrivate)
@@ -132,8 +132,7 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
                 result = d->mTrackData[index.row()].title();
             } else {
                 if (d->mData[index.row()].mTrackUrl.isLocalFile()) {
-                    auto localFile = QFileInfo(d->mData[index.row()].mTrackUrl.toLocalFile());
-                    result = localFile.fileName();
+                    result = d->mData[index.row()].mTrackUrl.fileName();
                 } else {
                     result = d->mData[index.row()].mTrackUrl.toString();
                 }
@@ -350,14 +349,14 @@ bool MediaPlayList::setData(const QModelIndex &index, const QVariant &value, int
         return modelModified;
     }
 
-    ColumnsRoles convertedRole = static_cast<ColumnsRoles>(role);
+    auto convertedRole = static_cast<ColumnsRoles>(role);
 
     switch(convertedRole)
     {
     case ColumnsRoles::IsPlayingRole:
     {
         modelModified = true;
-        PlayState newState = static_cast<PlayState>(value.toInt());
+        auto newState = static_cast<PlayState>(value.toInt());
         d->mData[index.row()].mIsPlaying = newState;
         Q_EMIT dataChanged(index, index, {role});
 
@@ -768,6 +767,50 @@ void MediaPlayList::enqueueArtists(const QList<QString> &artistNames,
     }
 }
 
+void MediaPlayList::enqueue(const QList<QUrl> &trackUrls,
+                            ElisaUtils::PlayListEnqueueMode enqueueMode,
+                            ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    if (trackUrls.isEmpty()) {
+        return;
+    }
+
+    if (enqueueMode == ElisaUtils::ReplacePlayList) {
+        clearPlayList();
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + trackUrls.size() - 1);
+    for (const auto &oneTrackUrl : trackUrls) {
+        d->mData.push_back(MediaPlayListEntry{oneTrackUrl});
+        d->mTrackData.push_back({});
+        if (oneTrackUrl.isValid()) {
+            qDebug() << "MediaPlayList::enqueue" << "newTrackByFileNameInList" << oneTrackUrl;
+            if (oneTrackUrl.isLocalFile()) {
+                QFileInfo newTrackFile(oneTrackUrl.toLocalFile());
+                if (newTrackFile.exists()) {
+                    d->mData.last().mIsValid = true;
+                }
+                Q_EMIT newTrackByFileNameInList(oneTrackUrl);
+            }
+        }
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT ensurePlay();
+    }
+}
+
   void MediaPlayList::replaceAndPlay(qulonglong newTrackId)
 {
     clearPlayList();
@@ -1295,7 +1338,7 @@ void MediaPlayList::resetCurrentTrack()
 
 void MediaPlayList::notifyCurrentTrackChanged()
 {
-    Q_EMIT currentTrackChanged();
+    Q_EMIT currentTrackChanged(d->mCurrentTrack);
     Q_EMIT currentTrackRowChanged();
     bool currentTrackIsValid = d->mCurrentTrack.isValid();
     if (currentTrackIsValid) {
