@@ -20,6 +20,8 @@
 #ifndef MUSICALBUM_H
 #define MUSICALBUM_H
 
+#include "elisaLib_export.h"
+
 #include "musicaudiotrack.h"
 
 #include <QString>
@@ -33,7 +35,7 @@
 class MusicAlbumPrivate;
 class QDebug;
 
-class MusicAlbum
+class ELISALIB_EXPORT MusicAlbum
 {
 
 public:
@@ -94,6 +96,10 @@ public:
 
     bool isSingleDiscAlbum() const;
 
+    void setGenres(const QStringList &aGenres);
+
+    QStringList genres() const;
+
     void setTracks(const QList<MusicAudioTrack> &allTracks);
 
     const MusicAudioTrack &trackFromIndex(int index) const;
